pub struct NewAgentAnnotation {
pub agent_id: Uuid,
pub key: String,
pub value: String,
}Expand description
Represents a new agent annotation to be inserted into the database.
JSON schema
{
"description": "Represents a new agent annotation to be inserted into the database.",
"type": "object",
"required": [
"agent_id",
"key",
"value"
],
"properties": {
"agent_id": {
"description": "ID of the agent this annotation belongs to.",
"type": "string",
"format": "uuid"
},
"key": {
"description": "Key of the annotation (max 64 characters, no whitespace).",
"type": "string"
},
"value": {
"description": "Value of the annotation (max 64 characters, no whitespace).",
"type": "string"
}
}
}Fields
agent_id: UuidID of the agent this annotation belongs to.
key: StringKey of the annotation (max 64 characters, no whitespace).
value: StringValue of the annotation (max 64 characters, no whitespace).
Implementations
Sourceimpl NewAgentAnnotation
impl NewAgentAnnotation
pub fn builder() -> NewAgentAnnotation