pub struct NewAgentTarget {
pub agent_id: Uuid,
pub stack_id: Uuid,
}Expand description
Represents a new agent target to be inserted into the database.
JSON schema
{
"description": "Represents a new agent target to be inserted into the database.",
"type": "object",
"required": [
"agent_id",
"stack_id"
],
"properties": {
"agent_id": {
"description": "ID of the agent to associate with a stack.",
"type": "string",
"format": "uuid"
},
"stack_id": {
"description": "ID of the stack to associate with an agent.",
"type": "string",
"format": "uuid"
}
}
}Fields
agent_id: UuidID of the agent to associate with a stack.
stack_id: UuidID of the stack to associate with an agent.
Implementations
Sourceimpl NewAgentTarget
impl NewAgentTarget
pub fn builder() -> NewAgentTarget