pub struct NewStack {
pub description: Option<String>,
pub generator_id: Uuid,
pub name: String,
}Expand description
Represents a new stack to be inserted into the database.
JSON schema
{
"description": "Represents a new stack to be inserted into the database.",
"type": "object",
"required": [
"generator_id",
"name"
],
"properties": {
"description": {
"description": "Optional description of the stack.",
"type": [
"string",
"null"
]
},
"generator_id": {
"description": "Optional generator ID.",
"type": "string",
"format": "uuid"
},
"name": {
"description": "Name of the stack.",
"type": "string"
}
}
}Fields
description: Option<String>Optional description of the stack.
generator_id: UuidOptional generator ID.
name: StringName of the stack.
Implementations