pub struct NewStackAnnotation {
pub key: String,
pub stack_id: Uuid,
pub value: String,
}Expand description
Represents a new stack annotation to be inserted into the database.
JSON schema
{
"description": "Represents a new stack annotation to be inserted into the database.",
"type": "object",
"required": [
"key",
"stack_id",
"value"
],
"properties": {
"key": {
"description": "Key of the annotation (max 64 characters, no whitespace).",
"type": "string"
},
"stack_id": {
"description": "ID of the stack this annotation belongs to.",
"type": "string",
"format": "uuid"
},
"value": {
"description": "Value of the annotation (max 64 characters, no whitespace).",
"type": "string"
}
}
}Fields
key: StringKey of the annotation (max 64 characters, no whitespace).
stack_id: UuidID of the stack this annotation belongs to.
value: StringValue of the annotation (max 64 characters, no whitespace).
Implementations
Sourceimpl NewStackAnnotation
impl NewStackAnnotation
pub fn builder() -> NewStackAnnotation