pub struct StackLabel {
pub id: Uuid,
pub label: String,
pub stack_id: Uuid,
}Expand description
Represents a stack label in the database.
JSON schema
{
"description": "Represents a stack label in the database.",
"type": "object",
"required": [
"id",
"label",
"stack_id"
],
"properties": {
"id": {
"description": "Unique identifier for the stack label.",
"type": "string",
"format": "uuid"
},
"label": {
"description": "The label text (max 64 characters, no whitespace).",
"type": "string"
},
"stack_id": {
"description": "ID of the stack this label is associated with.",
"type": "string",
"format": "uuid"
}
}
}Fields
id: UuidUnique identifier for the stack label.
label: StringThe label text (max 64 characters, no whitespace).
stack_id: UuidID of the stack this label is associated with.
Implementations
Sourceimpl StackLabel
impl StackLabel
pub fn builder() -> StackLabel