pub struct TemplateAnnotation {
pub created_at: DateTime<Utc>,
pub id: Uuid,
pub key: String,
pub template_id: Uuid,
pub value: String,
}Expand description
Represents a template annotation in the database.
JSON schema
{
"description": "Represents a template annotation in the database.",
"type": "object",
"required": [
"created_at",
"id",
"key",
"template_id",
"value"
],
"properties": {
"created_at": {
"description": "Timestamp when the annotation was created.",
"type": "string",
"format": "date-time"
},
"id": {
"description": "Unique identifier for the template annotation.",
"type": "string",
"format": "uuid"
},
"key": {
"description": "The annotation key (max 64 characters, no whitespace).",
"type": "string"
},
"template_id": {
"description": "ID of the template this annotation is associated with.",
"type": "string",
"format": "uuid"
},
"value": {
"description": "The annotation value (max 64 characters, no whitespace).",
"type": "string"
}
}
}Fields
created_at: DateTime<Utc>Timestamp when the annotation was created.
id: UuidUnique identifier for the template annotation.
key: StringThe annotation key (max 64 characters, no whitespace).
template_id: UuidID of the template this annotation is associated with.
value: StringThe annotation value (max 64 characters, no whitespace).
Implementations
Sourceimpl TemplateAnnotation
impl TemplateAnnotation
pub fn builder() -> TemplateAnnotation